#ifndef _X11_STRINGDEFS_H_
#define _X11_STRINGDEFS_H_


#ifdef __cplusplus
extern "C" {
#endif





    extern char XtStrings[];
#ifdef __cplusplus
}
#endif
#endif
